@@ -1,34 +1,34 @@
 # coding=utf-8
-from Products.Five.testbrowser import Browser
 from euphorie.client import model
-from osha.oira.client.interfaces import IOSHAClientSkinLayer
 from euphorie.client.tests.test_model import createSurvey
 from euphorie.ghost import PathGhost
 from osha.oira.client import utils
+from osha.oira.client.interfaces import IOSHAClientSkinLayer
 from osha.oira.tests.base import OiRAFunctionalTestCase
 from osha.oira.tests.base import OiRATestCase
+from Products.Five.testbrowser import Browser
 from z3c.saconfig import Session
 from zope import component
 from zope import interface
+
 import datetime
 
 
 class EuphorieReportTests(OiRAFunctionalTestCase):
     def testUnicodeReportFilename(self):
-        from euphorie.content.tests.utils import BASIC_SURVEY
         from euphorie.client.tests.utils import addSurvey
         from euphorie.client.tests.utils import registerUserInClient
+        from euphorie.content.tests.utils import BASIC_SURVEY
+
         # Test for http://code.simplon.biz/tracker/euphorie/ticket/156
         self.loginAsPortalOwner()
         addSurvey(self.portal, BASIC_SURVEY)
         browser = Browser()
-        survey_url = \
-            self.portal.client.nl["ict"]["software-development"].absolute_url()
+        survey_url = self.portal.client.nl["ict"]["software-development"].absolute_url()
         browser.open(survey_url)
         registerUserInClient(browser)
         # Create a new survey session
-        browser.getControl(name="title:utf8:ustring").value = \
-            u"Sessiøn".encode("utf-8")
+        browser.getControl(name="title:utf8:ustring").value = u"Sessiøn".encode("utf-8")
         browser.getControl(name="next").click()
         # Start the survey
         browser.getForm().submit()
@@ -41,23 +41,23 @@ class EuphorieReportTests(OiRAFunctionalTestCase):
         self.assertEqual(browser.headers.type, "application/rtf")
         self.assertEqual(
             browser.headers.get("Content-Disposition"),
-            'attachment; filename="Action plan Sessi\xc3\xb8n.rtf"')
+            'attachment; filename="Action plan Sessi\xc3\xb8n.rtf"',
+        )
 
     def testInvalidDateDoesNotBreakRendering(self):
-        from euphorie.content.tests.utils import BASIC_SURVEY
         from euphorie.client.tests.utils import addSurvey
         from euphorie.client.tests.utils import registerUserInClient
+        from euphorie.content.tests.utils import BASIC_SURVEY
+
         # Test for http://code.simplon.biz/tracker/tno-euphorie/ticket/150
         self.loginAsPortalOwner()
         addSurvey(self.portal, BASIC_SURVEY)
         browser = Browser()
-        survey_url = \
-            self.portal.client.nl["ict"]["software-development"].absolute_url()
+        survey_url = self.portal.client.nl["ict"]["software-development"].absolute_url()
         browser.open(survey_url)
         registerUserInClient(browser)
         # Create a new survey session
-        browser.getControl(name="title:utf8:ustring").value = \
-            u"Sessiøn".encode("utf-8")
+        browser.getControl(name="title:utf8:ustring").value = u"Sessiøn".encode("utf-8")
         browser.getControl(name="next").click()
         # Start the survey
         browser.getForm().submit()
@@ -65,52 +65,53 @@ class EuphorieReportTests(OiRAFunctionalTestCase):
         # Update the risk
         risk = Session.query(model.Risk).first()
         risk.identification = "no"
-        risk.action_plans.append(model.ActionPlan(
-            action_plan=u"Do something awesome",
-            planning_start=datetime.date(1, 2, 3)))
+        risk.action_plans.append(
+            model.ActionPlan(
+                action_plan=u"Do something awesome",
+                planning_start=datetime.date(1, 2, 3),
+            )
+        )
         # Render the report
         browser.handleErrors = False
-        browser.open("http://nohost/plone/client/nl/ict/"
-                     "software-development/report/view")
+        browser.open(
+            "http://nohost/plone/client/nl/ict/" "software-development/report/view"
+        )
         # No errors = success
 
     def testCountryDefaultsToCurrentCountry(self):
-        from euphorie.content.tests.utils import BASIC_SURVEY
         from euphorie.client.tests.utils import addSurvey
         from euphorie.client.tests.utils import registerUserInClient
+        from euphorie.content.tests.utils import BASIC_SURVEY
+
         self.loginAsPortalOwner()
         addSurvey(self.portal, BASIC_SURVEY)
         browser = Browser()
-        survey_url = \
-            self.portal.client.nl["ict"]["software-development"].absolute_url()
+        survey_url = self.portal.client.nl["ict"]["software-development"].absolute_url()
         browser.open(survey_url)
         registerUserInClient(browser)
         # Create a new survey session
-        browser.getControl(name="title:utf8:ustring").value = \
-            u"Sessiøn".encode("utf-8")
+        browser.getControl(name="title:utf8:ustring").value = u"Sessiøn".encode("utf-8")
         browser.getControl(name="next").click()
         # Start the survey
         browser.getForm().submit()
         browser.getLink("Start Risk Identification").click()
         # Check the company data
         browser.open("%s/report/company" % survey_url)
-        self.assertEqual(
-            browser.getControl(name="form.widgets.country").value, ["nl"])
+        self.assertEqual(browser.getControl(name="form.widgets.country").value, ["nl"])
 
     def testCompanySettingsRoundTrip(self):
-        from euphorie.content.tests.utils import BASIC_SURVEY
         from euphorie.client.tests.utils import addSurvey
         from euphorie.client.tests.utils import registerUserInClient
+        from euphorie.content.tests.utils import BASIC_SURVEY
+
         self.loginAsPortalOwner()
         addSurvey(self.portal, BASIC_SURVEY)
         browser = Browser()
-        survey_url = \
-            self.portal.client.nl["ict"]["software-development"].absolute_url()
+        survey_url = self.portal.client.nl["ict"]["software-development"].absolute_url()
         browser.open(survey_url)
         registerUserInClient(browser)
         # Create a new survey session
-        browser.getControl(name="title:utf8:ustring").value = \
-            u"Sessiøn".encode("utf-8")
+        browser.getControl(name="title:utf8:ustring").value = u"Sessiøn".encode("utf-8")
         browser.getControl(name="next").click()
         # Start the survey
         browser.getForm().submit()
@@ -121,32 +122,31 @@ class EuphorieReportTests(OiRAFunctionalTestCase):
         browser.getControl(name="form.widgets.employees").value = ["50-249"]
         browser.getControl(name="form.widgets.conductor").value = ["staff"]
         browser.getControl(name="form.widgets.referer").value = ["trade-union"]
-        browser.getControl(name="form.widgets.workers_participated").value = \
-            ['True']
+        browser.getControl(name="form.widgets.workers_participated").value = ["True"]
         browser.getControl(name="form.buttons.next").click()
         # Make sure all fields validated
         self.assertEqual(browser.url, "%s/report/view" % survey_url)
         # Verify entered data
         browser.open("%s/report/company" % survey_url)
+        self.assertEqual(browser.getControl(name="form.widgets.country").value, ["be"])
         self.assertEqual(
-            browser.getControl(name="form.widgets.country").value, ["be"])
+            browser.getControl(name="form.widgets.employees").value, ["50-249"]
+        )
         self.assertEqual(
-            browser.getControl(name="form.widgets.employees").value,
-            ["50-249"])
+            browser.getControl(name="form.widgets.conductor").value, ["staff"]
+        )
         self.assertEqual(
-            browser.getControl(name="form.widgets.conductor").value, ["staff"])
+            browser.getControl(name="form.widgets.referer").value, ["trade-union"]
+        )
         self.assertEqual(
-            browser.getControl(name="form.widgets.referer").value,
-            ["trade-union"])
-        self.assertEqual(
-            browser.getControl(name="form.widgets.workers_participated").value,
-            ["True"])
+            browser.getControl(name="form.widgets.workers_participated").value, ["True"]
+        )
 
 
 class ActionPlanTimelineTests(OiRAFunctionalTestCase):
-
     def ActionPlanTimeline(self, *a, **kw):
         from osha.oira.client.report import ActionPlanTimeline
+
         return ActionPlanTimeline(*a, **kw)
 
     def createSurveySession(self):
@@ -154,8 +154,8 @@ class ActionPlanTimelineTests(OiRAFunctionalTestCase):
         account = model.Account(loginname=u"jane", password=u"secret")
         self.sqlsession.add(account)
         self.session = model.SurveySession(
-            title=u"Session",
-            zodb_path="nl/dining/survey", account=account)
+            title=u"Session", zodb_path="nl/dining/survey", account=account
+        )
         self.sqlsession.add(self.session)
         self.sqlsession.flush()
         return self.session
@@ -165,9 +165,9 @@ class ActionPlanTimelineTests(OiRAFunctionalTestCase):
         session = self.createSurveySession()
         module = model.Module(
             depth=1,
-            title=u'Root Module',
-            module_id='1',
-            zodb_path='1',
+            title=u"Root Module",
+            module_id="1",
+            zodb_path="1",
             skip_children=False,
             profile_index=0,
         )
@@ -175,9 +175,9 @@ class ActionPlanTimelineTests(OiRAFunctionalTestCase):
 
         nested_module1 = model.Module(
             depth=2,
-            title=u'Nested Module 1',
-            module_id='2',
-            zodb_path='1/1',
+            title=u"Nested Module 1",
+            module_id="2",
+            zodb_path="1/1",
             skip_children=False,
             profile_index=1,
         )
@@ -185,9 +185,9 @@ class ActionPlanTimelineTests(OiRAFunctionalTestCase):
 
         nested_module2 = model.Module(
             depth=3,
-            title=u'Nested Module 2',
-            module_id='3',
-            zodb_path='1/1/1',
+            title=u"Nested Module 2",
+            module_id="3",
+            zodb_path="1/1/1",
             skip_children=False,
             profile_index=2,
         )
@@ -195,17 +195,18 @@ class ActionPlanTimelineTests(OiRAFunctionalTestCase):
 
         risk = model.Risk(
             depth=4,
-            title=u'Floors are washed',
-            risk_id='1',
-            zodb_path='1/1/1/1',
-            type='risk',
-            priority=u'low',
-            identification='no',
+            title=u"Floors are washed",
+            risk_id="1",
+            zodb_path="1/1/1/1",
+            type="risk",
+            priority=u"low",
+            identification="no",
             action_plans=[
                 model.ActionPlan(
-                action_plan=u"Do something awesome",
-                planning_start=datetime.date(2013, 3, 4))
-            ]
+                    action_plan=u"Do something awesome",
+                    planning_start=datetime.date(2013, 3, 4),
+                )
+            ],
         )
         nested_module2.addChild(risk)
 
@@ -215,18 +216,17 @@ class ActionPlanTimelineTests(OiRAFunctionalTestCase):
         self.assertEqual(len(measures), 1)
         self.assertEqual(
             measures[0][0].title,
-            u'Nested Module 2',
+            u"Nested Module 2",
         )
 
     def test_get_measures_with_profile_questions(self):
-        """ Test for #7322 and #8850
-        """
+        """Test for #7322 and #8850"""
         session = self.createSurveySession()
         question = model.Module(
             depth=1,
-            title=u'(Repeatable Module) Do you have multiple shops?',
-            module_id='1',
-            zodb_path='1',
+            title=u"(Repeatable Module) Do you have multiple shops?",
+            module_id="1",
+            zodb_path="1",
             skip_children=False,
             profile_index=-1,
         )
@@ -234,14 +234,15 @@ class ActionPlanTimelineTests(OiRAFunctionalTestCase):
 
         i = 0
         for module_title in [
-            u'(Repeating instance) Somerset West',
-            u'(Repeating instance) Stellenbosch']:
+            u"(Repeating instance) Somerset West",
+            u"(Repeating instance) Stellenbosch",
+        ]:
 
             answer = model.Module(
                 depth=2,
                 title=module_title,
-                module_id='2',
-                zodb_path='1',
+                module_id="2",
+                zodb_path="1",
                 skip_children=False,
                 profile_index=i,
             )
@@ -250,17 +251,18 @@ class ActionPlanTimelineTests(OiRAFunctionalTestCase):
             answer.addChild(
                 model.Risk(
                     depth=3,
-                    title=u'Hands are washed',
-                    risk_id='1',
-                    zodb_path='1/2',
-                    type='risk',
-                    priority=u'low',
-                    identification='no',
+                    title=u"Hands are washed",
+                    risk_id="1",
+                    zodb_path="1/2",
+                    type="risk",
+                    priority=u"low",
+                    identification="no",
                     action_plans=[
                         model.ActionPlan(
-                        action_plan=u"Do something awesome",
-                        planning_start=datetime.date(2013, 3, 4))
-                    ]
+                            action_plan=u"Do something awesome",
+                            planning_start=datetime.date(2013, 3, 4),
+                        )
+                    ],
                 )
             )
             i += 1
@@ -272,11 +274,11 @@ class ActionPlanTimelineTests(OiRAFunctionalTestCase):
         self.assertEqual(len(measures), 2)
         self.assertEqual(
             measures[0][0].title,
-            u'(Repeating instance) Somerset West',
+            u"(Repeating instance) Somerset West",
         )
         self.assertEqual(
             measures[1][0].title,
-            u'(Repeating instance) Stellenbosch',
+            u"(Repeating instance) Stellenbosch",
         )
 
     def test_get_measures_with_profile_questions_and_submodules(self):
@@ -284,9 +286,9 @@ class ActionPlanTimelineTests(OiRAFunctionalTestCase):
         session = self.createSurveySession()
         question = model.Module(
             depth=1,
-            title=u'(Repeatable Module) Do you have multiple shops?',
-            module_id='1',
-            zodb_path='1',
+            title=u"(Repeatable Module) Do you have multiple shops?",
+            module_id="1",
+            zodb_path="1",
             skip_children=False,
             profile_index=-1,
         )
@@ -294,26 +296,27 @@ class ActionPlanTimelineTests(OiRAFunctionalTestCase):
 
         i = 0
         for module_title in [
-            u'(Repeating instance) Somerset West',
-            u'(Repeating instance) Stellenbosch']:
+            u"(Repeating instance) Somerset West",
+            u"(Repeating instance) Stellenbosch",
+        ]:
 
-            location_path = '%s/%d' % (question.zodb_path, i)
+            location_path = "%s/%d" % (question.zodb_path, i)
             location = model.Module(
                 depth=3,
                 title=module_title,
-                module_id='2',
+                module_id="2",
                 zodb_path=location_path,
                 skip_children=False,
                 profile_index=i,
             )
             question.addChild(location)
 
-            submodule_path = '%s/1' % location_path
+            submodule_path = "%s/1" % location_path
             submodule = model.Module(
                 depth=2,
-                title=u'Nested Module 1',
-                module_id='2',
-                zodb_path='%s/1' % location_path,
+                title=u"Nested Module 1",
+                module_id="2",
+                zodb_path="%s/1" % location_path,
                 skip_children=False,
                 profile_index=1,
             )
@@ -322,17 +325,18 @@ class ActionPlanTimelineTests(OiRAFunctionalTestCase):
             submodule.addChild(
                 model.Risk(
                     depth=4,
-                    title=u'Hands are washed',
-                    risk_id='1',
-                    zodb_path='%s/%d' % (submodule_path, i),
-                    type='risk',
-                    priority=u'low',
-                    identification='no',
+                    title=u"Hands are washed",
+                    risk_id="1",
+                    zodb_path="%s/%d" % (submodule_path, i),
+                    type="risk",
+                    priority=u"low",
+                    identification="no",
                     action_plans=[
                         model.ActionPlan(
-                        action_plan=u"Do something awesome",
-                        planning_start=datetime.date(2013, 3, 4))
-                    ]
+                            action_plan=u"Do something awesome",
+                            planning_start=datetime.date(2013, 3, 4),
+                        )
+                    ],
                 )
             )
             i += 1
@@ -343,131 +347,170 @@ class ActionPlanTimelineTests(OiRAFunctionalTestCase):
         self.assertEqual(len(measures), 2)
         self.assertEqual(
             measures[0][0].title,
-            u'Nested Module 1',
+            u"Nested Module 1",
         )
         self.assertEqual(
             measures[1][0].title,
-            u'Nested Module 1',
+            u"Nested Module 1",
         )
 
     def test_get_measures_order_by_priority(self):
         session = self.createSurveySession()
         module = model.Module(
-            title=u'Root',
-            module_id='1',
-            zodb_path='1',
-            skip_children=False)
+            title=u"Root", module_id="1", zodb_path="1", skip_children=False
+        )
         session.addChild(module)
-        module.addChild(model.Risk(
-            title=u'Risk 1', risk_id='2', zodb_path='1/2', type='risk',
-            priority=u'low', identification='no',
-            action_plans=[model.ActionPlan(
-                action_plan=u"Do something awesome",
-                planning_start=datetime.date(2013, 3, 4))]))
-        module.addChild(model.Risk(
-            title=u'Risk 2', risk_id='3', zodb_path='1/3', type='risk',
-            priority=u'high', identification='no',
-            action_plans=[model.ActionPlan(
-                action_plan=u"Do something awesome",
-                planning_start=datetime.date(2013, 5, 2))]))
-        module.addChild(model.Risk(
-            title=u'Risk 3', risk_id='4', zodb_path='1/4', type='risk',
-            priority=u'medium', identification='no',
-            action_plans=[model.ActionPlan(
-                action_plan=u"Do something awesome",
-                planning_start=datetime.date(2013, 4, 1))]))
+        module.addChild(
+            model.Risk(
+                title=u"Risk 1",
+                risk_id="2",
+                zodb_path="1/2",
+                type="risk",
+                priority=u"low",
+                identification="no",
+                action_plans=[
+                    model.ActionPlan(
+                        action_plan=u"Do something awesome",
+                        planning_start=datetime.date(2013, 3, 4),
+                    )
+                ],
+            )
+        )
+        module.addChild(
+            model.Risk(
+                title=u"Risk 2",
+                risk_id="3",
+                zodb_path="1/3",
+                type="risk",
+                priority=u"high",
+                identification="no",
+                action_plans=[
+                    model.ActionPlan(
+                        action_plan=u"Do something awesome",
+                        planning_start=datetime.date(2013, 5, 2),
+                    )
+                ],
+            )
+        )
+        module.addChild(
+            model.Risk(
+                title=u"Risk 3",
+                risk_id="4",
+                zodb_path="1/4",
+                type="risk",
+                priority=u"medium",
+                identification="no",
+                action_plans=[
+                    model.ActionPlan(
+                        action_plan=u"Do something awesome",
+                        planning_start=datetime.date(2013, 4, 1),
+                    )
+                ],
+            )
+        )
 
         view = self.ActionPlanTimeline(None, None)
         view.session = self.session
         measures = view.get_measures()
         self.assertEqual(
             [risk.priority for (m, risk, measure) in measures],
-            [u'high', u'medium', u'low'])
+            [u"high", u"medium", u"low"],
+        )
 
 
 class RiskQueryTests(OiRATestCase):
-    """ Test #7547
+    """Test #7547
 
-        A risk with evaluation method 'fixed' (i.e. skip_evaluation=true)
-        and which has been identified, should appear in the final report
-        as identified but without action plan.
+    A risk with evaluation method 'fixed' (i.e. skip_evaluation=true)
+    and which has been identified, should appear in the final report
+    as identified but without action plan.
     """
 
     def createData(self):
         (self.session, self.survey_session) = createSurvey()
 
-        self.q1 = model.Module(**{
-            'depth': 1,
-            'module_id': 1,
-            'has_description': True,
-            'path': u'001',
-            'postponed': None,
-            'profile_index': -1,
-            'skip_children': False,
-            'title': u'What is the sound of one hand clapping?',
-            'type': u'module',
-            'zodb_path': u'173'
-        })
+        self.q1 = model.Module(
+            **{
+                "depth": 1,
+                "module_id": 1,
+                "has_description": True,
+                "path": u"001",
+                "postponed": None,
+                "profile_index": -1,
+                "skip_children": False,
+                "title": u"What is the sound of one hand clapping?",
+                "type": u"module",
+                "zodb_path": u"173",
+            }
+        )
         self.survey_session.addChild(self.q1)
 
-        self.mod1 = model.Module(**{
-            'depth': 2,
-            'module_id': 2,
-            'has_description': True,
-            'path': u'001001',
-            'postponed': None,
-            'profile_index': 0,
-            'skip_children': False,
-            'title': u'Stellenbosch',
-            'type': u'module',
-            'zodb_path': u'173'
-        })
+        self.mod1 = model.Module(
+            **{
+                "depth": 2,
+                "module_id": 2,
+                "has_description": True,
+                "path": u"001001",
+                "postponed": None,
+                "profile_index": 0,
+                "skip_children": False,
+                "title": u"Stellenbosch",
+                "type": u"module",
+                "zodb_path": u"173",
+            }
+        )
         self.q1.addChild(self.mod1)
 
-        self.r1 = model.Risk(**{
-            'risk_id': 1,
-            'depth': 3,
-            'identification': 'no',
-            'action_plans': [],
-            'has_description': True,
-            'path': u'001001001',
-            'postponed': False,
-            'profile_index': 0,
-            'skip_children': False,
-            'title': u'Hands are washed',
-            'type': u'risk',
-            'zodb_path': u'173/euphorie.risk'
-        })
+        self.r1 = model.Risk(
+            **{
+                "risk_id": 1,
+                "depth": 3,
+                "identification": "no",
+                "action_plans": [],
+                "has_description": True,
+                "path": u"001001001",
+                "postponed": False,
+                "profile_index": 0,
+                "skip_children": False,
+                "title": u"Hands are washed",
+                "type": u"risk",
+                "zodb_path": u"173/euphorie.risk",
+            }
+        )
         self.mod1.addChild(self.r1)
 
-        self.mod2 = model.Module(**{
-            'depth': 2,
-            'module_id': 3,
-            'has_description': True,
-            'path': u'001002',
-            'postponed': None,
-            'profile_index': 1,
-            'skip_children': False,
-            'title': u'Somerset West',
-            'type': u'module',
-            'zodb_path': u'173'
-        })
+        self.mod2 = model.Module(
+            **{
+                "depth": 2,
+                "module_id": 3,
+                "has_description": True,
+                "path": u"001002",
+                "postponed": None,
+                "profile_index": 1,
+                "skip_children": False,
+                "title": u"Somerset West",
+                "type": u"module",
+                "zodb_path": u"173",
+            }
+        )
         self.q1.addChild(self.mod2)
 
-        self.r2 = model.Risk(**{
-            'risk_id': 1,
-            'depth': 3,
-            'identification': 'yes',
-            'action_plans': [],
-            'has_description': True,
-            'path': u'001002001',
-            'postponed': False,
-            'profile_index': 1,
-            'skip_children': False,
-            'title': u'Hands are washed',
-            'type': u'risk',
-            'zodb_path': u'173/euphorie.risk'
-        })
+        self.r2 = model.Risk(
+            **{
+                "risk_id": 1,
+                "depth": 3,
+                "identification": "yes",
+                "action_plans": [],
+                "has_description": True,
+                "path": u"001002001",
+                "postponed": False,
+                "profile_index": 1,
+                "skip_children": False,
+                "title": u"Hands are washed",
+                "type": u"risk",
+                "zodb_path": u"173/euphorie.risk",
+            }
+        )
         self.mod2.addChild(self.r2)
 
         # self.r3 = model.Risk(**{
@@ -493,7 +536,8 @@ class RiskQueryTests(OiRATestCase):
 
         interface.alsoProvides(self.portal.REQUEST, IOSHAClientSkinLayer)
         view = component.getMultiAdapter(
-            (PathGhost('dummy'), self.portal.REQUEST), name="download")
+            (PathGhost("dummy"), self.portal.REQUEST), name="download"
+        )
 
         view.session = self.survey_session
         if view.session.company is None:
@@ -504,20 +548,20 @@ class RiskQueryTests(OiRATestCase):
 
     def testActionedNodes(self):
         self.createData()
-        query = Session().query(model.SurveyTreeItem)\
-            .filter(model.SurveyTreeItem.session == self.survey_session)\
+        query = (
+            Session()
+            .query(model.SurveyTreeItem)
+            .filter(model.SurveyTreeItem.session == self.survey_session)
             .order_by(model.SurveyTreeItem.path)
+        )
 
         nodes = query.all()
         self.assertEqual(len(utils.get_actioned_nodes(nodes)), 0)
 
     def testUnansweredNodes(self):
         self.createData()
-        self.assertEqual(
-            len(utils.get_unanswered_nodes(self.survey_session)), 0)
+        self.assertEqual(len(utils.get_unanswered_nodes(self.survey_session)), 0)
 
     def testRiskNotPresentNodes(self):
         self.createData()
-        self.assertEqual(
-            len(utils.get_risk_not_present_nodes(self.survey_session)), 3)
-
+        self.assertEqual(len(utils.get_risk_not_present_nodes(self.survey_session)), 3)
